==> haskell-wl-pprint-text-1.1.1.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-text
version: 1.1.1.0
id: wl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ
key: wl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ
license: BSD3
copyright: 2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
synopsis: A Wadler/Leijen Pretty Printer for Text values
description:
    A clone of wl-pprint for use with the text library.
category: Text
author: Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic
abi: 4f7012fd58ac52dc37744a7dc9135c92
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-text-1.1.1.0
hs-libraries: HSwl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-text-1.1.1.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-text
version: 1.1.1.0
id: wl-pprint-text-1.1.1.0-FXfvn1QOy6yCo2Dt9jMvti
key: wl-pprint-text-1.1.1.0-FXfvn1QOy6yCo2Dt9jMvti
license: BSD3
copyright: 2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
synopsis: A Wadler/Leijen Pretty Printer for Text values
description:
    A clone of wl-pprint for use with the text library.
category: Text
author: Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic
abi: d3e049c0a22004602f4150b7f68e6016
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wl-pprint-text-1.1.1.0
hs-libraries: HSwl-pprint-text-1.1.1.0-FXfvn1QOy6yCo2Dt9jMvti
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=b23a246a62afd271167dd1ea1b77583b
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
